
###################
### 1 - Erne-filter
query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length
t=8 # Threads
i=20 # quality parameter
out=lovell_ernefilter-${i}
erne-filter --query1 $query1 --query2 $query2 --output-prefix $out --min-size $minsize --min-phred-value-mott ${i} --min-mean-phred-quality ${i} --gzip --threads $t



###################
### 2 - Cutadapt
# Cannot work on paired data (need extra treatment for "orphan" reads)
query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

ORPHANS=removeOrphans.pl
SANGER_TO_ILLUMINA=fastq_sanger_to_illumina.pl
ILLUMINA_TO_SANGER=fastq_illumina_to_sanger.pl

i=20 # quality parameter
cutadapt --minimum-length=$minsize --quality-cutoff=${i} $query1 | gzip - > lovell_cutadapt-${i}.raw1.fastq.gz
cutadapt --minimum-length=$minsize --quality-cutoff=${i} $query2 | gzip - > lovell_cutadapt-${i}.raw2.fastq.gz
input1=lovell_cutadapt-${i}.raw1.fastq.gz
input2=lovell_cutadapt-${i}.raw2.fastq.gz
output1=lovell_cutadapt-${i}_1.fastq.gz
output2=lovell_cutadapt-${i}_2.fastq.gz
outputU=lovell_cutadapt-${i}_unpaired.fastq.gz
perl $ORPHANS --input1=$input1 --input2=$input2 --output1=$output1 --output2=$output2 --outputU=$outputU
rm $input1 && rm $input2


###################
### 3 - Condetri
CONDETRI=condetri_v2.2.pl # Obtained from authors' website
query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

lq=10 # LQ quality parameter
hq=25 # HQ quality parameter

out=lovell_condetri-hq${hq}-lq${lq}
perl $CONDETRI -fastq1=$query1 -fastq2=$query2 -prefix=$out -minlen=$minsize -sc=33 -hq=$hq -lq=$lq
rm ${out}.stats
gzip ${out}_trim1.fastq && gzip ${out}_trim2.fastq && gzip ${out}_trim_unpaired.fastq
rm ${out}_trim1.fastq && rm ${out}_trim2.fastq && rm ${out}_trim_unpaired.fastq


###################
### 4 - SolexaQA
SOLEXAQA=DynamicTrim.pl # Obtained from authors' website
ORPHANS=removeOrphans.pl
TRIMLENGTH=trimFastqLength.pl

query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

i=20 # quality parameter
mkdir lovell_solexaqa-${i}_1
mkdir lovell_solexaqa-${i}_2
zcat $query1 | perl $SOLEXAQA - -h ${i} -d lovell_solexaqa-${i}_1
zcat $query2 | perl $SOLEXAQA - -h ${i} -d lovell_solexaqa-${i}_2
cat lovell_solexaqa-${i}_1/-.trimmed | perl $TRIMLENGTH $minsize > lovell_solexaqa-temp-${i}_1.fastq
cat lovell_solexaqa-${i}_2/-.trimmed | perl $TRIMLENGTH $minsize > lovell_solexaqa-temp-${i}_2.fastq
rm -R lovell_solexaqa-${i}_1/ lovell_solexaqa-${i}_2/
input1=lovell_solexaqa-temp-${i}_1.fastq
input2=lovell_solexaqa-temp-${i}_2.fastq
output1=lovell_solexaqa-${i}_1.fastq.gz
output2=lovell_solexaqa-${i}_2.fastq.gz
outputU=lovell_solexaqa-${i}_unpaired.fastq.gz
perl $ORPHANS --input1=$input1 --input2=$input2 --output1=$output1 --output2=$output2 --outputU=$outputU
rm $input1 && rm $input2



###################
### 4B - SolexaQA with BWA algorithm
SOLEXAQA=DynamicTrim.pl # Obtained from authors' website
ORPHANS=removeOrphans.pl
TRIMLENGTH=trimFastqLength.pl

query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

i=20 # quality parameter
mkdir lovell_solexaqaBWA-${i}_1
mkdir lovell_solexaqaBWA-${i}_2
zcat $query1 | perl $SOLEXAQA - -h ${i} -bwa -d lovell_solexaqaBWA-${i}_1
zcat $query2 | perl $SOLEXAQA - -h ${i} -bwa -d lovell_solexaqaBWA-${i}_2
cat lovell_solexaqaBWA-${i}_1/-.trimmed | perl $TRIMLENGTH $minsize | gzip -c > lovell_solexaqaBWA-${i}.raw1.fastq.gz
cat lovell_solexaqaBWA-${i}_2/-.trimmed | perl $TRIMLENGTH $minsize | gzip -c > lovell_solexaqaBWA-${i}.raw2.fastq.gz
rm -R lovell_solexaqaBWA-${i}_1/ lovell_solexaqaBWA-${i}_2/

input1=lovell_solexaqaBWA-${i}.raw1.fastq.gz
input2=lovell_solexaqaBWA-${i}.raw2.fastq.gz
output1=lovell_solexaqaBWA-${i}_1.fastq.gz
output2=lovell_solexaqaBWA-${i}_2.fastq.gz
outputU=lovell_solexaqaBWA-${i}_unpaired.fastq.gz
perl $ORPHANS --input1=$input1 --input2=$input2 --output1=$output1 --output2=$output2 --outputU=$outputU
rm $input1 && rm $input2



###################
### 5 - Prinseq
# Cannot work on paired data (need extra treatment for "orphan" reads)
PRINSEQ=prinseq-lite.pl # Obtained from authors' website
ORPHANS=removeOrphans.pl

query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

i=20 # quality parameter
zcat $query1 | perl $PRINSEQ -fastq stdin -min_len $minsize -trim_qual_left $i -trim_qual_right $i -out_good stdout -out_bad null -out_format 3 | gzip -c > lovell_prinseq-${i}.raw1.fastq.gz
zcat $query2 | perl $PRINSEQ -fastq stdin -min_len $minsize -trim_qual_left $i -trim_qual_right $i -out_good stdout -out_bad null -out_format 3 | gzip -c > lovell_prinseq-${i}.raw2.fastq.gz
input1=lovell_prinseq-${i}.raw1.fastq.gz
input2=lovell_prinseq-${i}.raw2.fastq.gz
output1=lovell_prinseq-${i}_1.fastq.gz
output2=lovell_prinseq-${i}_2.fastq.gz
outputU=lovell_prinseq-${i}_unpaired.fastq.gz
perl $ORPHANS --input1=$input1 --input2=$input2 --output1=$output1 --output2=$output2 --outputU=$outputU
rm $input1 && rm $input2



###################
### 6 - Trimmomatic
TRIMMOMATIC=/home/fgiorgi/programs/Trimmomatic-0.22/trimmomatic-0.22.jar # Obtained from authors' website

query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

i=20 # quality parameter
java -Xmx2000M -classpath $TRIMMOMATIC org.usadellab.trimmomatic.TrimmomaticPE -phred33 $query1 $query2 lovell_trimmomatic-${i}_1.fastq.gz lovell_trimmomatic-${i}_U1.fastq.gz lovell_trimmomatic-${i}_2.fastq.gz lovell_trimmomatic-${i}_U2.fastq.gz LEADING:3 TRAILING:3 SLIDINGWINDOW:4:${i} MINLEN:$minsize
zcat lovell_trimmomatic-${i}_U1.fastq.gz lovell_trimmomatic-${i}_U2.fastq.gz | gzip > lovell_trimmomatic-${i}_unpaired.fastq.gz
rm lovell_trimmomatic-${i}_U1.fastq.gz && rm lovell_trimmomatic-${i}_U2.fastq.gz



###################
### 7 - FastX quality trimmer
# Need to treat orphan reads (cannot work on paired data
# Need to convert to Phred+64 quality score (and back to Phred+33)

query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

SANGER_TO_ILLUMINA=fastq_sanger_to_illumina.pl
ILLUMINA_TO_SANGER=fastq_illumina_to_sanger.pl
ORPHANS=removeOrphans.pl

i=20 # quality parameter
zcat $query1 | perl $SANGER_TO_ILLUMINA | fastq_quality_trimmer -t ${i} -l $minsize -o lovell_fastx-${i}.raw1.fastq
zcat $query2 | perl $SANGER_TO_ILLUMINA | fastq_quality_trimmer -t ${i} -l $minsize -o lovell_fastx-${i}.raw2.fastq
cat lovell_fastx-${i}.raw1.fastq | perl $ILLUMINA_TO_SANGER > temp_${i} && mv temp_${i} lovell_fastx-${i}.raw1.fastq
cat lovell_fastx-${i}.raw2.fastq | perl $ILLUMINA_TO_SANGER > temp_${i} && mv temp_${i} lovell_fastx-${i}.raw2.fastq
input1=lovell_fastx-${i}.raw1.fastq
input2=lovell_fastx-${i}.raw2.fastq
output1=lovell_fastx-${i}_1.fastq.gz
output2=lovell_fastx-${i}_2.fastq.gz
outputU=lovell_fastx-${i}_unpaired.fastq.gz
perl $ORPHANS --input1=$input1 --input2=$input2 --output1=$output1 --output2=$output2 --outputU=$outputU
rm $input1 && rm $input2


###################
### 8 - Sickle
query1=lovell_1.fastq.gz
query2=lovell_2.fastq.gz
minsize=70 # 70% of original length

i=20 # quality parameter
sickle pe -t sanger -q $i -l $minsize -f $query1 -r $query2 -o lovell_sickle-${i}_1.fastq -p lovell_sickle-${i}_2.fastq -s lovell_sickle-${i}_unpaired.fastq
gzip lovell_sickle-${i}_1.fastq lovell_sickle-${i}_2.fastq lovell_sickle-${i}_unpaired.fastq


