#!/usr/local/bin/perl
####################################################################
# Description: takes two fastq files and reports only paired reads #
####################################################################

use warnings;
use strict;
use Getopt::Long;
use Pod::Usage;
use Bio::Perl;


my $input1;
my $input2;
my $output1;
my $output2;
my $outputU;
my $help = 0;

GetOptions(
	'input1=s'  => \$input1,
	'input2=s'  => \$input2,
	'output1=s' => \$output1,
	'output2=s' => \$output2,
	'outputU=s' => \$outputU,
	'help|?'    => \$help
) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(1)
  if ( !defined($input1)
	or !defined($input2)
	or !defined($output1)
	or !defined($output2)
	or !defined($outputU) );


### First file loop
# If input is gzipped
if ($input1 =~ /\.gz$/) {
	open(INPUT1, "zcat $input1 |");
}
if ($input2 =~ /\.gz$/) {
	open(INPUT2, "zcat $input2 |");
}

# If input is normal
if ($input1 !~ /\.gz$/) {
	open(INPUT1, "<$input1");
}
if ($input2 !~ /\.gz$/) {
	open(INPUT2, "<$input2");
}


my %count_read;
my $count_line = 0;
while ( my $line = <INPUT1> ) {
	if ( $count_line % 4 == 0 ) {
		chomp $line;
		my @array = split( /[\/\s]/, $line );
		my $readname = $array[0];
		$count_read{$readname} = 1;
	}
	$count_line++;
}
close INPUT1;

$count_line = 0;
while ( my $line = <INPUT2> ) {
	if ( $count_line % 4 == 0 ) {
		chomp $line;
		my @array = split( /[\/\s]/, $line );
		my $readname = $array[0];
		if ( exists( $count_read{$readname} ) ) {
			$count_read{$readname} = 2;
		}
		else {
			$count_read{$readname} = 1;
		}
	}
	$count_line++;
}
close INPUT2;


### Second file loop
# If input is gzipped
if ($input1 =~ /\.gz$/) {
	open(INPUT1, "zcat $input1 |");
}
if ($input2 =~ /\.gz$/) {
	open(INPUT2, "zcat $input2 |");
}

# If input is normal
if ($input1 !~ /\.gz$/) {
	open(INPUT1, "<$input1");
}
if ($input2 !~ /\.gz$/) {
	open(INPUT2, "<$input2");
}

open(OUTPUT1, "| gzip -c > $output1") or die $!;
open(OUTPUT2, "| gzip -c > $output2") or die $!;
open(OUTPUTU, "| gzip -c > $outputU") or die $!;

$count_line = 0;
my $printpaired = 0;
my $printorphan = 0;
while ( my $line = <INPUT1> ) {
	chomp $line;
	if ( $count_line % 4 == 0 ) {
		my @array = split( /[\/\s]/, $line );
		my $readname = $array[0];
		if ( $count_read{$readname} == 2 ) {
			$printpaired = 1;
			$printorphan = 0;
		}
		elsif ( $count_read{$readname} == 1 ) {
			$printpaired = 0;
			$printorphan = 1;
		}
		else {
			$printpaired = 0;
			$printorphan = 0;
		}
	}
	if ($printpaired) {
		print OUTPUT1 $line . "\n";
	}
	if ($printorphan) {
		print OUTPUTU $line . "\n";
	}
	$count_line++;
}
close INPUT1;
close OUTPUT1;

$count_line  = 0;
$printpaired = 0;
while ( my $line = <INPUT2> ) {
	chomp $line;
	if ( $count_line % 4 == 0 ) {
		my @array = split( /[\/\s]/, $line );
		my $readname = $array[0];
		if ( $count_read{$readname} == 2 ) {
			$printpaired = 1;
			$printorphan = 0;
		}
		elsif ( $count_read{$readname} == 1 ) {
			$printpaired = 0;
			$printorphan = 1;
		}
		else {
			$printpaired = 0;
			$printorphan = 0;
		}
	}
	if ($printpaired) {
		print OUTPUT2 $line . "\n";
	}
	if ($printorphan) {
		print OUTPUTU $line . "\n";
	}
	$count_line++;
}
close INPUT2;
close OUTPUT2;

close OUTPUTU;
__END__


=head1 GFF Statistics

removeOrphans.pl - Using this script

=head1 SYNOPSIS

perl removeOrphans.pl [--input1 <filename>] [--input2 <filename>] [--output1 <filename>] [--output2 <filename>] [--outputU <filename>] [--help]


  Options:
    --input1 <filename>		first fastq input file
    --input2 <filename>		second fastq input file
    --output1 <filename>	first fastq output file
    --output2 <filename>	second fastq output file
    --outputU <filename>  orphan fastq output file
    --help			print this help message

output on standard output (redirect, if necessary)

